@@ -19,10 +19,11 @@
 
 #include <cassert>
 #include <cstdlib>
+#include <stdexcept>
 
 #include "RL1.h"
-#include "Timer.h"
-#include "log.h"
+// #include "Timer.h"
+// #include "log.h"
 
 using namespace goss;
 
@@ -51,13 +52,13 @@ void RL1::attach(std::shared_ptr<ODE> ode)
     ODESolver::attach(ode);
 
     if (_ode->is_dae())
-        goss_error("RL1.cpp", "attach ode", "cannot integrate a DAE ode with Rush Larsen method.");
+        // goss_error("RL1.cpp", "attach ode", "cannot integrate a DAE ode with Rush Larsen method.");
+        throw std::runtime_error("cannot integrate a DAE ode with Rush Larsen method.");
 }
 //-----------------------------------------------------------------------------
 void RL1::forward(double *y, double t, double dt)
 {
 
-
     // Calculate number of steps and size of timestep based on _ldt
     const double ldt_0 = _ldt;
     const ulong nsteps = ldt_0 > 0 ? std::ceil(dt / ldt_0 - 1.0E-12) : 1;
@@ -66,7 +67,8 @@ void RL1::forward(double *y, double t, double dt)
     // Local time
     double lt = t;
 
-    for (ulong step = 0; step < nsteps; ++step) {
+    for (ulong step = 0; step < nsteps; ++step)
+    {
 
         // One step
         _one_step(y, y, y, lt, ldt);
