@@ -23,12 +23,12 @@
 namespace goss
 {
 
-  // Unsigned integers
-  typedef unsigned int uint;
+// Unsigned integers
+typedef unsigned int uint;
 
-  // Unsigned long
-  typedef unsigned long ulong;
+// Unsigned long
+typedef unsigned long ulong;
 
-}
+} // namespace goss
 
 #endif
