@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import hashlib
+import typing
 from enum import Enum
 from typing import Any
 
@@ -185,7 +186,7 @@ class GossCodeGeneratorParameters(BaseModel):
     generate_jacobian: bool = Field(False, description="Generate Jacobian matrix")
     generate_lu_factorization: bool = Field(
         False,
-        description="Geneate Lu factorization",
+        description="Generate Lu factorization",
     )
     optimize_exprs: OptimizeExprs = Field(
         OptimizeExprs.none,
@@ -212,7 +213,6 @@ class GossCodeGeneratorParameters(BaseModel):
         table.add_column("Description", style="green")
 
         for k, v in schema["properties"].items():
-
             t = v.get("type", "")
             desc = v.get("description", "")
 
@@ -233,10 +233,10 @@ class GossCodeGenerator(CppCodeGenerator):
     def __init__(
         self,
         ode,
-        field_states: list[str] = None,
-        field_parameters: list[str] = None,
-        monitored: list[str] = None,
-        code_params: dict[str, Any] = None,
+        field_states: typing.Optional[list[str]] = None,
+        field_parameters: typing.Optional[list[str]] = None,
+        monitored: typing.Optional[list[str]] = None,
+        code_params: typing.Optional[dict[str, Any]] = None,
         add_signature_to_name: bool = False,
     ):
         """
@@ -254,7 +254,7 @@ class GossCodeGenerator(CppCodeGenerator):
             A list of names of intermediates of the ODE. Code for monitoring
             the intermediates will be generated.
         code_params : dict
-            Parameters controling the code generation
+            Parameters controlling the code generation
         """
 
         field_states = field_states or []
@@ -392,7 +392,7 @@ class GossCodeGenerator(CppCodeGenerator):
         ode = self.ode
 
         # State names
-        state_names = [state.name for state in ode.full_states]
+        state_names = [state.name for state in ode.states]
         body = ["", "// State names"]
         body.extend(
             '_state_names[{0}] = "{1}"'.format(i, name)
@@ -575,13 +575,12 @@ class GossCodeGenerator(CppCodeGenerator):
             "eval",
             "uint id, const double* states, double time",
             return_type="double",
-            comment="Evaluate componenttwise rhs of the ODE",
+            comment="Evaluate componentwise rhs of the ODE",
         )
         code = "\n".join(self.indent_and_split_lines(body, indent=2))
         self.class_form["eval_componentwise_code"] = "\n" + code + "\n"
 
     def _eval_linearized_code(self):
-
         lin = linearized_derivatives(
             self.ode,
             function_name="linearized_eval",
@@ -641,7 +640,6 @@ class GossCodeGenerator(CppCodeGenerator):
             self.class_form["jacobian_code"] = "\n" + code + "\n"
 
         if self.params.functions.lu_factorization.generate:
-
             if jac is None:
                 jac = jacobian_expressions(
                     self.ode,
@@ -664,7 +662,6 @@ class GossCodeGenerator(CppCodeGenerator):
             self.class_form["factorizing_code"] = "\n" + code + "\n"
 
         if self.params.functions.forward_backward_subst.generate:
-
             if jac is None:
                 jac = jacobian_expressions(
                     self.ode,
@@ -691,7 +688,7 @@ class GossCodeGenerator(CppCodeGenerator):
                 body,
                 "forward_backward_subst",
                 "const double* jac, const double* b, double* dx",
-                comment="Forward/Backward substitution of factoriesed matrix",
+                comment="Forward/Backward substitution of factorized matrix",
                 const=True,
             )
             code = "\n".join(self.indent_and_split_lines(body, indent=2))
