@@ -19,10 +19,10 @@ here = Path(__file__).parent.absolute()
 
 def cppyy_jit(
     ode: gotran.ODE,
-    field_states: list[str] = None,
-    field_parameters: list[str] = None,
-    monitored: list[str] = None,
-    code_params: dict[str, typing.Any] = None,
+    field_states: typing.Optional[list[str]] = None,
+    field_parameters: typing.Optional[list[str]] = None,
+    monitored: typing.Optional[list[str]] = None,
+    code_params: typing.Optional[dict[str, typing.Any]] = None,
 ) -> ctypes.c_void_p:
     """
     Generate a goss::ODEParameterized from a gotran ode and JIT compile it
@@ -39,7 +39,7 @@ def cppyy_jit(
         A list of names of intermediates of the ODE. Code for monitoring
         the intermediates will be generated.
     code_params : dict
-        Parameters controling the code generation
+        Parameters controlling the code generation
     """
 
     # Code generators
@@ -61,7 +61,6 @@ def cppyy_jit(
 
 
 def code_to_submodule(code: str, name):
-
     import cppyy
 
     cppyy.add_include_path(here.joinpath("include").as_posix())
@@ -85,10 +84,10 @@ def make_ode(python_object):
 
 def jit(
     ode: gotran.ODE,
-    field_states: list[str] = None,
-    field_parameters: list[str] = None,
-    monitored: list[str] = None,
-    code_params: dict[str, typing.Any] = None,
+    field_states: typing.Optional[list[str]] = None,
+    field_parameters: typing.Optional[list[str]] = None,
+    monitored: typing.Optional[list[str]] = None,
+    code_params: typing.Optional[dict[str, typing.Any]] = None,
 ):
     """
     Generate a goss::ODEParameterized from a gotran ode and JIT compile it
@@ -105,7 +104,7 @@ def jit(
         A list of names of intermediates of the ODE. Code for monitoring
         the intermediates will be generated.
     code_params : dict
-        Parameters controling the code generation
+        Parameters controlling the code generation
     """
 
     python_object = cppyy_jit(
