@@ -214,7 +214,6 @@ def setup_dofs(
     domains: typing.Optional[dolfin.cpp.mesh.MeshFunctionSizet] = None,
     distinct_domains: typing.Optional[list[int]] = None,
 ):
-
     mesh = V.mesh()
 
     num_field_states = len(field_names)
@@ -320,7 +319,6 @@ def setup_dofs(
 
     # Allocate memory for accessing values from DOLFIN Function
     if nested_dofs:
-
         # Always use np.float_ for the dolfin_values
         dolfin_values = np.concatenate(
             tuple(value for value in goss_values.values()),
@@ -357,7 +355,6 @@ def check_domains_dim(domains, family):
 
 
 def check_domains(domains, odes, mesh, space) -> list[int]:
-
     family, degree = family_and_degree_from_str(space)
 
     assert isinstance(domains, dolfin.cpp.mesh.MeshFunctionSizet), (
@@ -400,7 +397,12 @@ class DOLFINODESystemSolver:
 
     @staticmethod
     def default_parameters():
-        return {"solver": "GRL1", "num_threads": 0, "use_cuda": False}
+        return {
+            "solver": "GRL1",
+            "num_threads": 0,
+            "use_cuda": False,
+            "space": "P_1",
+        }
 
     @staticmethod
     def default_parameters_dolfin():
@@ -414,7 +416,6 @@ class DOLFINODESystemSolver:
         mesh,
         odes,
         domains=None,
-        space="P_1",
         params=None,
     ):
         """
@@ -440,12 +441,9 @@ class DOLFINODESystemSolver:
             "expected a dolfin Mesh " "or domain for the mesh argument"
         )
         assert isinstance(odes, (dict, ParameterizedODE)), (
-            "expected a" " dict or a ParametersizedODE for the odes argument"
+            "expected a" " dict or a ParameterizedODE for the odes argument"
         )
 
-        # Get family and degree from str
-        family, degree = family_and_degree_from_str(space)
-
         params = params or {}
 
         self.parameters = self.default_parameters()
@@ -455,10 +453,17 @@ class DOLFINODESystemSolver:
         solver.update_parameters(self.parameters.get("solver_parameters", {}))
 
         odes = DOLFINParameterizedODE.convert(odes)
+        # Get family and degree from str
+        family, degree = family_and_degree_from_str(self.parameters["space"])
 
         distinct_domains = [0]
         if len(odes) > 1:
-            distinct_domains = check_domains(domains, odes, mesh, space)
+            distinct_domains = check_domains(
+                domains,
+                odes,
+                mesh,
+                self.parameters["space"],
+            )
         # else:
 
         # FIXME: Do we really need to check this?
@@ -472,9 +477,22 @@ class DOLFINODESystemSolver:
         distinct_domains = list(odes.keys())
 
         if num_field_states > 1:
-            V = dolfin.VectorFunctionSpace(mesh, family, degree, dim=num_field_states)
+            element = dolfin.VectorElement(
+                family=family,
+                cell=mesh.ufl_cell(),
+                degree=degree,
+                quad_scheme="default",
+                dim=num_field_states,
+            )
+
         else:
-            V = dolfin.FunctionSpace(mesh, family, degree)
+            element = dolfin.FiniteElement(
+                family=family,
+                cell=mesh.ufl_cell(),
+                degree=degree,
+                quad_scheme="default",
+            )
+        V = dolfin.FunctionSpace(mesh, element)
 
         dofs = setup_dofs(
             V=V,
@@ -521,7 +539,6 @@ class DOLFINODESystemSolver:
 
             # Check for any field params on this domain
             if len(ode.field_params) > 0:
-
                 # function space of parameter Function
                 V_param = first_value(ode.field_params).function_space()
 
@@ -657,7 +674,6 @@ class DOLFINODESystemSolver:
 
         # Update solver with new field_state values
         for label, ode_system_solver in self._ode_system_solvers.items():
-
             # Fetch solution from stored field states
             self._dofs.goss_values[label] = ode_system_solver.field_states.ravel()
 
@@ -684,7 +700,6 @@ class DOLFINODESystemSolver:
         V = self.vs.function_space()
         # Update solver with new field_state values
         for label, ode_system_solver in self._ode_system_solvers.items():
-
             ic = ode_system_solver.ode.field_state_initial_conditions()
             values = dolfin.interpolate(ic, V).vector().get_local()
 
@@ -714,7 +729,6 @@ class DOLFINODESystemSolver:
 
         # Update solver with new field_state values
         for label, ode_system_solver in self._ode_system_solvers.items():
-
             # Iterate over the fields and collect values if nested dofs
             if self._dofs.nested_dofs:
                 for field_name in self._field_names:
@@ -787,6 +801,6 @@ class DOLFINODESystemSolver:
         if not self._saved_states:
             raise RuntimeError("Cannot restore any states when none are saved.")
 
-        # Restor the states from the saved one
+        # Restore the states from the saved one
         for label, ode_system_solver in self._ode_system_solvers.items():
             ode_system_solver.states()[:] = self._saved_states[label]
