@@ -1,11 +1,10 @@
+import platform
 from pathlib import Path
 
 import goss
 import numpy as np
 import pytest
 
-# import scipy.linalg
-
 
 here = Path(__file__).parent.absolute()
 
@@ -20,7 +19,6 @@ def test_get_ic(oscilator):
 
 
 def test_ode_eval_full(oscilator):
-
     values = oscilator.eval(np.array([0.1, 0.2]), 0)
     assert np.allclose(values, np.array([-0.2, 0.1]))
 
@@ -48,6 +46,10 @@ def test_ode_eval_index(oscilator):
     assert np.isclose(oscilator.eval_component(1, np.array([0.1, 0.2]), 0), 0.1)
 
 
+@pytest.mark.skipif(
+    platform.processor() == "arm",
+    reason="https://github.com/wlav/cppyy/issues/68",
+)
 def test_ode_eval_index_out_of_bounds_raises_RuntimeError(oscilator):
     with pytest.raises(RuntimeError):
         oscilator.eval_component(3, np.array([0.1, 0.2]), 0)
@@ -64,7 +66,6 @@ def test_ode_compute_jacobian_oscilator(oscilator):
 
 
 def test_ode_jacobian_tentusscher_2004(tentusscher_2004):
-
     ic = tentusscher_2004.get_ic()
     jac = tentusscher_2004.compute_jacobian(ic, 0)
     # jac_orig = jac.copy()
@@ -97,7 +98,6 @@ def test_monitored_values(fitzhughnagumo_ode):
 
 @pytest.mark.parametrize("only_linear", [True, False])
 def test_linearized_rhs_only_linear_True(oscilator, only_linear):
-
     states = np.array([0.1, 0.2])
     rhs, linear = oscilator.linearized_eval(states, 0, only_linear)
 
@@ -108,13 +108,23 @@ def test_linearized_rhs_only_linear_True(oscilator, only_linear):
     assert np.allclose(rhs, np.array([-0.2, 0.1]))
 
 
-def test_ode_contructors(oscilator_ode):
+def test_ode_contractors(oscilator_ode):
     ode = goss.ODE(oscilator_ode)
     ode_copy = ode.copy()
     ode_path = goss.ODE(here.joinpath("oscilator.ode"))
     assert ode.num_states == ode_copy.num_states == ode_path.num_states
 
 
-def test_invalid_ode_construtor():
+def test_invalid_ode_constructor():
     with pytest.raises(ValueError):
         goss.ODE(42)
+
+
+def test_ode_state_names_ordering(tentusscher_2004_ode):
+    ode = goss.ParameterizedODE(tentusscher_2004_ode)
+    assert ode.state_names == tentusscher_2004_ode.state_symbols
+
+
+def test_ode_parameter_names_ordering(tentusscher_2004_ode):
+    ode = goss.ParameterizedODE(tentusscher_2004_ode)
+    assert ode.parameter_names == tentusscher_2004_ode.parameter_symbols
